==> nivo-0.9.0.tgz: package/es/components/charts/radar/RadarShapes.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import { range, max, maxBy, sumBy, uniq } from 'lodash-es';
import React from 'react';
import compose from 'recompose/compose';
import withPropsOnChange from 'recompose/withPropsOnChange';
import pure from 'recompose/pure';
import PropTypes from 'prop-types';
import { merge } from 'lodash-es';
import { Motion } from 'react-motion';
import { motionPropTypes, curvePropMapping, closedCurvePropType } from '../../../props';
import { getInheritedColorGenerator } from '../../../lib/colorUtils';
import SmartMotion from '../../SmartMotion';
import { lineRadial } from 'd3-shape';

var RadarShapes = function RadarShapes(_ref) {
    var data = _ref.data,
        lineGenerator = _ref.lineGenerator,
        borderWidth = _ref.borderWidth,
        borderColor = _ref.borderColor,
        fillOpacity = _ref.fillOpacity,
        animate = _ref.animate,
        motionStiffness = _ref.motionStiffness,
        motionDamping = _ref.motionDamping;

    if (animate !== true) {
        return React.createElement(
            'g',
            null,
            data.map(function (serie) {
                var id = serie.id,
                    color = serie.color,
                    serieData = serie.data;


                return React.createElement(
                    'g',
                    { key: id },
                    React.createElement('path', {
                        d: lineGenerator(serieData),
                        fill: color,
                        fillOpacity: fillOpacity,
                        stroke: borderColor(serie),
                        strokeWidth: borderWidth
                    })
                );
            })
        );
    }

    var springConfig = {
        stiffness: motionStiffness,
        damping: motionDamping
    };

    return React.createElement(
        'g',
        null,
        data.map(function (serie) {
            var id = serie.id,
                color = serie.color,
                serieData = serie.data;


            return React.createElement(
                SmartMotion,
                {
                    key: id,
                    style: function style(spring) {
                        return {
                            d: spring(lineGenerator(serieData), springConfig),
                            fill: spring(color, springConfig),
                            stroke: spring(borderColor(serie), springConfig)
                        };
                    }
                },
                function (style) {
                    return React.createElement('path', _extends({ fillOpacity: fillOpacity, strokeWidth: borderWidth }, style));
                }
            );
        })
    );
};

RadarShapes.propTypes = _extends({
    // data
    data: PropTypes.arrayOf(PropTypes.shape({
        id: PropTypes.string.isRequired,
        data: PropTypes.arrayOf(PropTypes.number).isRequired
    })).isRequired,

    radiusScale: PropTypes.func.isRequired,
    angleStep: PropTypes.number.isRequired,

    curve: closedCurvePropType.isRequired,
    lineGenerator: PropTypes.func.isRequired,

    // border
    borderWidth: PropTypes.number.isRequired,
    borderColor: PropTypes.func.isRequired,

    // theming
    fillOpacity: PropTypes.number.isRequired

}, motionPropTypes);

var enhance = compose(withPropsOnChange(['borderColor'], function (props) {
    return {
        borderColor: getInheritedColorGenerator(props.borderColor)
    };
}), withPropsOnChange(['radiusScale', 'angleStep', 'curve'], function (_ref2) {
    var radiusScale = _ref2.radiusScale,
        angleStep = _ref2.angleStep,
        curve = _ref2.curve;
    return {
        lineGenerator: lineRadial().radius(function (d) {
            return radiusScale(d);
        }).angle(function (d, i) {
            return i * angleStep;
        }).curve(curvePropMapping[curve])
    };
}), pure);

export default enhance(RadarShapes);

==> nivo-0.15.0.tgz: package/es/components/charts/radar/RadarShapes.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import { range, max, maxBy, sumBy, uniq } from 'lodash-es';
import React from 'react';
import compose from 'recompose/compose';
import withPropsOnChange from 'recompose/withPropsOnChange';
import pure from 'recompose/pure';
import PropTypes from 'prop-types';
import { merge } from 'lodash-es';
import { Motion } from 'react-motion';
import { motionPropTypes } from '../../../props';
import { getInheritedColorGenerator } from '../../../lib/colorUtils';
import SmartMotion from '../../SmartMotion';
import { lineRadial } from 'd3-shape';

var RadarShapes = function RadarShapes(_ref) {
    var data = _ref.data,
        lineGenerator = _ref.lineGenerator,
        borderWidth = _ref.borderWidth,
        borderColor = _ref.borderColor,
        fillOpacity = _ref.fillOpacity,
        animate = _ref.animate,
        motionStiffness = _ref.motionStiffness,
        motionDamping = _ref.motionDamping;

    if (animate !== true) {
        return React.createElement(
            'g',
            null,
            data.map(function (serie) {
                var id = serie.id,
                    color = serie.color,
                    serieData = serie.data;


                return React.createElement(
                    'g',
                    { key: id },
                    React.createElement('path', {
                        d: lineGenerator(serieData),
                        fill: color,
                        fillOpacity: fillOpacity,
                        stroke: borderColor(serie),
                        strokeWidth: borderWidth
                    })
                );
            })
        );
    }

    var springConfig = {
        stiffness: motionStiffness,
        damping: motionDamping
    };

    return React.createElement(
        'g',
        null,
        data.map(function (serie) {
            var id = serie.id,
                color = serie.color,
                serieData = serie.data;


            return React.createElement(
                SmartMotion,
                {
                    key: id,
                    style: function style(spring) {
                        return {
                            d: spring(lineGenerator(serieData), springConfig),
                            fill: spring(color, springConfig),
                            stroke: spring(borderColor(serie), springConfig)
                        };
                    }
                },
                function (style) {
                    return React.createElement('path', _extends({ fillOpacity: fillOpacity, strokeWidth: borderWidth }, style));
                }
            );
        })
    );
};

RadarShapes.propTypes = _extends({
    // data
    data: PropTypes.arrayOf(PropTypes.shape({
        id: PropTypes.string.isRequired,
        data: PropTypes.arrayOf(PropTypes.number).isRequired
    })).isRequired,

    radiusScale: PropTypes.func.isRequired,
    angleStep: PropTypes.number.isRequired,

    curveInterpolator: PropTypes.func.isRequired,
    lineGenerator: PropTypes.func.isRequired,

    // border
    borderWidth: PropTypes.number.isRequired,
    borderColor: PropTypes.func.isRequired,

    // theming
    fillOpacity: PropTypes.number.isRequired

}, motionPropTypes);

var enhance = compose(withPropsOnChange(['borderColor'], function (props) {
    return {
        borderColor: getInheritedColorGenerator(props.borderColor)
    };
}), withPropsOnChange(['radiusScale', 'angleStep', 'curveInterpolator'], function (_ref2) {
    var radiusScale = _ref2.radiusScale,
        angleStep = _ref2.angleStep,
        curveInterpolator = _ref2.curveInterpolator;
    return {
        lineGenerator: lineRadial().radius(function (d) {
            return radiusScale(d);
        }).angle(function (d, i) {
            return i * angleStep;
        }).curve(curveInterpolator)
    };
}), pure);

export default enhance(RadarShapes);
